@@ -70,16 +70,16 @@ pub enum QueryError {
 /// The sub-list member `e` would be identified via the path
 /// `foo`, `bar`, `baz`, `1`, `1`.
 #[derive(Debug)]
-pub struct Query {
+pub struct Query<'a> {
     /// The individual top-down components of this query.
-    route: Vec<Component>,
+    route: Vec<Component<'a>>,
 }
 
-impl Query {
+impl<'a> Query<'a> {
     /// Constructs a new query from the given path components.
     ///
     /// Returns `None` if the component list is empty.
-    pub fn new(route: Vec<Component>) -> Option<Self> {
+    pub fn new(route: Vec<Component<'a>>) -> Option<Self> {
         if route.is_empty() {
             None
         } else {
@@ -98,32 +98,32 @@ impl Query {
 
 /// A builder for [`Query`] objects.
 #[derive(Clone, Debug)]
-pub struct QueryBuilder {
-    route: Vec<Component>,
+pub struct QueryBuilder<'a> {
+    route: Vec<Component<'a>>,
 }
 
-impl Default for QueryBuilder {
+impl Default for QueryBuilder<'_> {
     fn default() -> Self {
         Self::new()
     }
 }
 
-impl QueryBuilder {
+impl<'a> QueryBuilder<'a> {
     /// Starts a new `QueryBuilder`.
     pub fn new() -> Self {
         Self { route: vec![] }
     }
 
     /// Adds a new key to the query being built.
-    pub fn key(mut self, key: impl Into<String>) -> Self {
-        self.route.push(Component::Key(key.into()));
+    pub fn key(mut self, key: &'a str) -> Self {
+        self.route.push(Component::Key(key));
         self
     }
 
     /// Adds multiple new keys to the query being built.
-    pub fn keys(mut self, keys: impl Iterator<Item = impl Into<String>>) -> Self {
+    pub fn keys(mut self, keys: impl Iterator<Item = &'a str>) -> Self {
         for key in keys {
-            self = self.key(key.into())
+            self = self.key(key)
         }
 
         self
@@ -139,16 +139,16 @@ impl QueryBuilder {
     /// it in the process.
     ///
     /// Panics unless at least one component has been added.
-    pub fn build(self) -> Query {
+    pub fn build(self) -> Query<'a> {
         Query::new(self.route).expect("API misuse: must add at least one component")
     }
 }
 
 /// A single `Query` component.
 #[derive(Clone, Debug, PartialEq)]
-pub enum Component {
+pub enum Component<'a> {
     /// A YAML key.
-    Key(String),
+    Key(&'a str),
 
     /// An index into a YAML array.
     Index(usize),
@@ -473,7 +473,7 @@ impl Document {
         {
             match component {
                 Component::Index(idx) => self.descend_sequence(&child, *idx),
-                Component::Key(key) => Err(QueryError::ExpectedMapping(key.into())),
+                Component::Key(key) => Err(QueryError::ExpectedMapping(key.to_string())),
             }
         } else {
             Err(QueryError::UnexpectedNode(child.kind().into()))
@@ -579,7 +579,7 @@ mod tests {
             .build();
         assert_eq!(
             query.parent().unwrap().route,
-            [Component::Key("foo".into()), Component::Key("bar".into())]
+            [Component::Key("foo"), Component::Key("bar")]
         );
 
         let query = QueryBuilder::new().keys(["foo"].into_iter()).build();
@@ -634,11 +634,11 @@ baz: quux
         assert_eq!(
             query.route,
             [
-                Component::Key("foo".into()),
-                Component::Key("bar".into()),
+                Component::Key("foo"),
+                Component::Key("bar"),
                 Component::Index(1),
                 Component::Index(123),
-                Component::Key("lol".into()),
+                Component::Key("lol"),
             ]
         )
     }
@@ -659,10 +659,10 @@ baz:
         let doc = Document::new(doc).unwrap();
         let query = Query {
             route: vec![
-                Component::Key("baz".into()),
-                Component::Key("sub".into()),
-                Component::Key("keys".into()),
-                Component::Key("abc".into()),
+                Component::Key("baz"),
+                Component::Key("sub"),
+                Component::Key("keys"),
+                Component::Key("abc"),
                 Component::Index(2),
                 Component::Index(3),
             ],
@@ -692,7 +692,7 @@ bar: # outside
 
         // Querying the root gives us all comments underneath it.
         let query = Query {
-            route: vec![Component::Key("root".into())],
+            route: vec![Component::Key("root")],
         };
         let feature = doc.query(&query).unwrap();
         assert_eq!(
@@ -704,8 +704,8 @@ bar: # outside
         // even though it's above it on the AST.
         let query = Query {
             route: vec![
-                Component::Key("root".into()),
-                Component::Key("e".into()),
+                Component::Key("root"),
+                Component::Key("e"),
                 Component::Index(1),
             ],
         };
